@@ -10,16 +10,23 @@
 #'
 #'
 pm3datalist<-function(data,x,y,covs,factor=NULL){
-  data<-as.data.frame(data)
-  data<-na.omit(data)
+  data<-data;covs<-covs
+  psid<-seq(1,dim(data)[1])
+  var<-c(x,y,covs)
   if (!missing(factor)) {factor<-factor}
-  data[,x]<-as.numeric(as.factor(data[,x]))
-  a<-unique(data[,x]);a<-sort(a);b<-c(1,2,3)
-  if (identical(a,b) !=TRUE)  {stop("X must be 3 categories.If x is a number, it must be 1,2,3.")}
   if (!missing(factor)) {
     for(i in factor){
       data[,i] <- as.factor(data[,i])
     }
   }
-  data
+  macdata<-data[,var];
+  macdata$psid<-psid
+  macdata<-as.data.frame(macdata)
+  macdata<-na.omit(macdata)
+  if (!length(levels(factor(macdata[,x])))==3) {stop("X must be 3 categories.")}
+  macdata[,x]<-as.numeric(factor(macdata[,x],labels = c(1,2,3)))
+  a<-unique(macdata[,x]);a<-sort(a);b<-c(1,2,3)
+  if (identical(a,b) !=TRUE)  {stop("X must be 3 categories.")}
+  macdata[,x]<-as.factor(macdata[,x])
+  macdata
 }
